ActionCallEnded class

Represents a call end event.

This event is triggered when a incoming or outgoing call is ended. This can happen when a user clicks on the "End" action from the notification.

Inheritance

Constructors

ActionCallEnded({required CallData data})
Creates an ActionCallEnded event instance with the specified data.
const

Properties

data CallData
The call data associated with the call that ended.
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited