ActionCallToggleHold class

Represents a call toggle hold event.

Note: This event is only available on iOS.

Inheritance

Constructors

ActionCallToggleHold({required String uuid, required bool isOnHold})
Creates an ActionCallToggleHold event instance with the specified uuid and isOnHold flag.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isOnHold bool
Indicates whether the call is on hold.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uuid String
The unique identifier for the call.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited