ActionDidUpdateDevicePushTokenVoip class

Event for updating the VoIP push token on the device (iOS specific).

Inheritance

Constructors

ActionDidUpdateDevicePushTokenVoip({required String token})
Creates an ActionDidUpdateDevicePushTokenVoip event instance with the specified token.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
token String
The updated device push token for VoIP.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited