CallData class

Represents call data with various properties related to the call.

This class encapsulates information about an ongoing or past call, including unique identifiers, caller's avatar, handle, name, video availability, and additional extra data associated with the call.

Constructors

CallData({String? uuid, String? callCid, String? avatar, String? handle, String? callerName, bool? hasVideo, Map<String, Object?>? extraData})
Creates a CallData instance with the provided details.
const

Properties

avatar String?
Avatar of the caller.
final
callCid String?
Call's unique identifier.
final
callerName String?
Name of the caller.
final
extraData Map<String, Object?>?
Extra data associated with the call.
final
handle String?
Handle of the caller.
final
hashCode int
The hash code for this object.
no setterinherited
hasVideo bool?
Indicates whether the call has video.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter
uuid String?
Unique identifier for the call.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited