CallParticipantState class

Implemented types
Annotations

Constructors

CallParticipantState({required String userId, required List<String> roles, required String name, @Deprecated('Use customData instead') required Map<String, Object?> custom, Map<String, Object?> customData = const {}, String? image, required String sessionId, required String trackIdPrefix, Map<SfuTrackType, TrackState> publishedTracks = const {}, Set<SfuTrackType> pausedTracks = const {}, bool isLocal = false, SfuConnectionQuality connectionQuality = SfuConnectionQuality.unspecified, bool isOnline = false, double audioLevel = 0, List<double>? audioLevels, bool isSpeaking = false, bool isDominantSpeaker = false, CallParticipantPin? pin, CallReaction? reaction, ViewportVisibility viewportVisibility = ViewportVisibility.unknown, ViewportVisibility screenShareViewportVisibility = ViewportVisibility.unknown, SfuParticipantSource? participantSource})

Properties

audioLevel double
The latest audio level for the user.
final
audioLevels List<double>
List of the last 10 audio levels.
final
audioTrack TrackState?
no setter
connectionQuality SfuConnectionQuality
final
custom Map<String, Object?>
final
customData Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
image String?
final
isAudioEnabled bool
no setter
isDominantSpeaker bool
final
isLocal bool
final
isOnline bool
final
isPinned bool
no setter
isScreenShareEnabled bool
no setter
isSpeaking bool
final
isVideoEnabled bool
no setter
name String
final
participantSource SfuParticipantSource?
final
pausedTracks Set<SfuTrackType>
A list of tracks that are currently paused by our servers. Typically, a server-side pause happens when the local participant doesn't have enough bandwidth to receive all tracks. In this case, the server will pause some tracks to optimize the bandwidth usage. Once the bandwidth is restored, the server will resume the paused tracks. This is useful to avoid any unwanted video and audio artifacts.
final
pin → CallParticipantPin?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
publishedTracks Map<SfuTrackType, TrackState>
final
reaction CallReaction?
final
roles List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenShareTrack TrackState?
no setter
screenShareViewportVisibility ViewportVisibility
final
sessionId String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
trackIdPrefix String
final
uniqueParticipantKey String
no setter
userId String
final
videoTrack TrackState?
no setter
viewportVisibility ViewportVisibility
final

Methods

compareTo(CallParticipantState other) int
Compares two participants.
override
copyWith({String? userId, List<String>? roles, String? name, Map<String, Object?>? custom, Map<String, Object?>? customData, String? image, String? sessionId, String? trackIdPrefix, Map<SfuTrackType, TrackState>? publishedTracks, Set<SfuTrackType>? pausedTracks, bool? isLocal, SfuConnectionQuality? connectionQuality, bool? isOnline, double? audioLevel, List<double>? audioLevels, bool? isSpeaking, bool? isDominantSpeaker, CallParticipantPin? pin, CallReaction? reaction, ViewportVisibility? viewportVisibility, ViewportVisibility? screenShareViewportVisibility, SfuParticipantSource? participantSource}) CallParticipantState
Returns a copy of this CallParticipantState with the given fields replaced with the new values.
copyWithPin({required CallParticipantPin? participantPin}) CallParticipantState
copyWithReaction({required CallReaction? reaction}) CallParticipantState
Returns a copy of this CallParticipantState with the reaction updated.
copyWithUpdatedAudioLevels({required double audioLevel, bool? isSpeaking}) CallParticipantState
Copies the current state and adds the latest audioLevel to the last 10 audioLevels.
isTrackPaused(SfuTrackType trackType) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
toUserInfo() UserInfo

Operators

operator ==(Object other) bool
The equality operator.
inherited