pausedTracks property
A list of tracks that are currently paused by our servers. Typically, a server-side pause happens when the local participant doesn't have enough bandwidth to receive all tracks. In this case, the server will pause some tracks to optimize the bandwidth usage. Once the bandwidth is restored, the server will resume the paused tracks. This is useful to avoid any unwanted video and audio artifacts.
Implementation
final Set<SfuTrackType> pausedTracks;