CallPreferredSizeWidgetBuilder typedef

CallPreferredSizeWidgetBuilder = PreferredSizeWidget? Function(BuildContext context, Call call)

Builder for parts of the call screen that need a PreferredSizeWidget. For example used to create a custom app bar.

Implementation

typedef CallPreferredSizeWidgetBuilder =
    PreferredSizeWidget? Function(
      BuildContext context,
      Call call,
    );