CallRejectReason class
Reason for rejecting a call.
busy - when the callee is busy and cannot accept the call decline - when the callee intentionally declines the call cancel - when the caller cancels the call timeout - when the call times out
Constructors
- CallRejectReason.busy()
-
factory
- CallRejectReason.cancel()
-
factory
- CallRejectReason.custom(String customType)
-
factory
- CallRejectReason.decline()
-
factory
- CallRejectReason.timeout()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited