CallRingingState enum

Inheritance
Available extensions

Values

ended → const CallRingingState
rejected → const CallRingingState
accepted → const CallRingingState
ringing → const CallRingingState

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isRinging bool

Available on CallRingingState, provided by the CallRingingStateX extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toReason() CallRejectReason?

Available on CallRingingState, provided by the CallRingingStateX extension

The reason to settle the local call state with once the ringing flow is over.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CallRingingState>
A constant List of the values in this enum, in order of their declaration.