CoordinatorCallMemberUpdatedEvent class

Inheritance
Available extensions

Constructors

CoordinatorCallMemberUpdatedEvent({required StreamCallCid callCid, required DateTime createdAt, required List<CallMember> members, required CallMetadata metadata})
const

Properties

callCid StreamCallCid
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
members List<CallMember>
final
metadata CallMetadata
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

mapToCallEvent(CallState state) StreamCallEvent?

Available on CoordinatorCallEvent, provided by the CoordinatorCallEventX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited