CoordinatorDisconnectedEvent class

Fired when web socket is closed.

Inheritance

Constructors

CoordinatorDisconnectedEvent({String? connectionId, String? userId, int? closeCode, String? closeReason})
const

Properties

closeCode int?
final
closeReason String?
final
connectionId String?
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited