DisconnectReason class abstract
- Annotations
Constructors
- DisconnectReason()
-
const
- DisconnectReason.blocked()
-
constfactory
- DisconnectReason.cancelled({required String byUserId})
-
constfactory
- DisconnectReason.ended()
-
factory
- DisconnectReason.failure(VideoError error)
-
constfactory
- DisconnectReason.lastParticipantLeft()
-
factory
- DisconnectReason.reconnectionFailed()
-
factory
- DisconnectReason.rejected({required String byUserId, CallRejectReason? reason})
-
constfactory
- DisconnectReason.replaced()
-
factory
- DisconnectReason.sfuError(SfuError error)
-
constfactory
- DisconnectReason.timeout()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited