FloatingViewContainer class

A widget that uses either SimpleFloatingView or SnappingFloatingView depending on the enableSnappingBehavior.

Inheritance

Constructors

FloatingViewContainer({Key? key, required Widget child, required Widget floatingView, required double floatingViewWidth, required double floatingViewHeight, bool enableSnappingBehavior = true, double floatingViewPadding = 16, FloatingViewAlignment floatingViewAlignment = FloatingViewAlignment.topRight})
Creates a new instance of FloatingViewContainer.
const

Properties

child Widget
The widget below this widget in the tree.
final
enableSnappingBehavior bool
If the floating view should be automatically anchored to one of the corners.
final
floatingView Widget
The widget that will be displayed as dragging widget.
final
floatingViewAlignment FloatingViewAlignment
The initial position of the floating view.
final
floatingViewHeight double
The height of the floating view.
final
floatingViewPadding double
The padding between floating view and the container.
final
floatingViewWidth double
The width of the floating view.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited