IOSPictureInPictureConfiguration class

Configuration options for enabling Picture-in-Picture (PiP) mode on iOS.

On iOS, multitasking camera access must be enabled to allow the user's camera to remain active while the app is in the background.

If multitasking camera access is enabled, setting includeLocalParticipantVideo to true allows the local camera feed to be used in PiP mode (true by default).

For more details, visit: https://getstream.io/video/docs/flutter/advanced/picture_in_picture/

Constructors

IOSPictureInPictureConfiguration({bool includeLocalParticipantVideo = true, bool showParticipantName = true, bool showMicrophoneIndicator = true, bool showConnectionQualityIndicator = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includeLocalParticipantVideo bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showConnectionQualityIndicator bool
final
showMicrophoneIndicator bool
final
showParticipantName bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited