IncomingVideoSettings class

Constructors

IncomingVideoSettings({required bool? enabled, required RtcVideoDimension? preferredResolution, required Map<String, ({bool enabled, RtcVideoDimension? preferredResolution})> participants})
IncomingVideoSettings.default_()
factory

Properties

enabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
participants Map<String, ({bool enabled, RtcVideoDimension? preferredResolution})>
final
preferredResolution RtcVideoDimension?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isParticipantVideoEnabled(String sessionId) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited