MuteToggleTitles class

Contains titles for muted and unmuted states.

Constructors

MuteToggleTitles({required String muteTitle, required String unmuteTitle})
Creates a new instance of MuteToggleTitles.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
muteTitle String
Title for unmuted state.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unmuteTitle String
Title for muted state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited