NetworkMonitorEndpoint class

Constructors

NetworkMonitorEndpoint({required String url, Map<String, String> headers = const {}, Duration timeout = const Duration(seconds: 3), List<int> validCodes = const [200]})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Headers to include in the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
The timeout for the request.
final
url String
The URL to check.
final
validCodes List<int>
List of HTTP status codes that are considered valid responses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInternetCheckOption() → InternetCheckOption
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited