OnUserAvatarLongPress typedef
OnUserAvatarLongPress =
void Function(UserInfo)
The action to perform when the user avatar is long-pressed.
Implementation
typedef OnUserAvatarLongPress = void Function(UserInfo);
The action to perform when the user avatar is long-pressed.
typedef OnUserAvatarLongPress = void Function(UserInfo);