PeerConnectionStats class
- Annotations
Constructors
-
PeerConnectionStats({required int? latency, required String? resolution, required String? qualityDropReason, required int? jitterInMs, required double? bitrateKbps, List<
String> ? videoCodec = const [], List<MediaStatsInfo> outboundMediaStats = const []}) -
const
- PeerConnectionStats.empty()
-
factory
Properties
- bitrateKbps → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- jitterInMs → int?
-
final
- latency → int?
-
final
-
outboundMediaStats
→ List<
MediaStatsInfo> -
final
- qualityDropReason → String?
-
final
- resolution → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
videoCodec
→ List<
String> ? -
final
Methods
-
copyWith(
{int? latency, String? resolution, String? qualityDropReason, int? jitterInMs, double? bitrateKbps, List< String> ? videoCodec, List<MediaStatsInfo> ? outboundMediaStats}) → PeerConnectionStats -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override