Priority enum

Inheritance
Implemented types
Available extensions

Values

verbose → const Priority
const Priority(level: 2)
debug → const Priority
const Priority(level: 3)
info → const Priority
const Priority(level: 4)
warning → const Priority
const Priority(level: 5)
error → const Priority
const Priority(level: 6)
none → const Priority
const Priority(level: 7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
level int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(Priority other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(Priority other) bool
operator <=(Priority other) bool
operator ==(Object other) bool
The equality operator.
inherited
operator >(Priority other) bool
operator >=(Priority other) bool

Constants

values → const List<Priority>
A constant List of the values in this enum, in order of their declaration.