RtcAudioSource class

Inheritance

Constructors

RtcAudioSource({String? id, String? type, double? timestamp, String? kind, String? trackIdentifier, double? audioLevel, double? totalAudioEnergy, double? totalSamplesDuration, double? echoReturnLoss, double? echoReturnLossEnhancement})
const

Properties

audioLevel double?
final
codecId String?
no setteroverride
echoReturnLoss double?
final
echoReturnLossEnhancement double?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
kind String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp double?
finalinherited
totalAudioEnergy double?
final
totalSamplesDuration double?
final
trackIdentifier String?
finalinherited
type String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
writeTo(StringBuffer out) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) RtcAudioSource?