RtcIceCandidatePair class

Inheritance

Constructors

RtcIceCandidatePair({String? id, String? type, double? timestamp, String? transportId, int? requestsSent, String? localCandidateId, int? bytesSent, int? bytesDiscardedOnSend, int? priority, int? requestsReceived, bool? writable, String? remoteCandidateId, int? bytesReceived, int? packetsReceived, int? responsesSent, int? packetsDiscardedOnSend, bool? nominated, int? packetsSent, double? totalRoundTripTime, int? responsesReceived, String? state, int? consentRequestsSent, double? currentRoundTripTime, double? availableOutgoingBitrate, double? availableIncomingBitrate})
const

Properties

availableIncomingBitrate double?
final
availableOutgoingBitrate double?
final
bytesDiscardedOnSend int?
final
bytesReceived int?
final
bytesSent int?
final
consentRequestsSent int?
final
currentRoundTripTime double?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
localCandidateId String?
final
nominated bool?
final
packetsDiscardedOnSend int?
final
packetsReceived int?
final
packetsSent int?
final
priority int?
final
remoteCandidateId String?
final
requestsReceived int?
final
requestsSent int?
final
responsesReceived int?
final
responsesSent int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final
timestamp double?
finalinherited
totalRoundTripTime double?
final
transportId String?
final
type String?
finalinherited
writable bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) RtcIceCandidatePair?