RtcInboundRtpVideoStream class

Inheritance
Implemented types

Constructors

RtcInboundRtpVideoStream({String? id, String? type, double? timestamp, String? transportId, int? qpSum, double? lastPacketReceivedTimestamp, int? nackCount, int? firCount, int? pliCount, int? packetsLost, int? keyFramesDecoded, double? totalSquaredInterFrameDelay, double? totalAssemblyTime, int? frameHeight, int? frameWidth, int? framesDropped, int? framesReceived, double? framesPerSecond, int? framesDecoded, double? totalInterFrameDelay, String? decoderImplementation, String? kind, String? trackId, double? jitterBufferDelay, int? ssrc, String? mediaType, double? minPlayoutDelay, int? headerBytesReceived, int? jitterBufferEmittedCount, String? codecId, int? bytesReceived, double? totalProcessingDelay, double? jitter, int? packetsReceived, double? totalDecodeTime})
const

Properties

bytesReceived int?
final
codecId String?
final
decoderImplementation String?
final
firCount int?
final
frameHeight int?
final
framesDecoded int?
final
framesDropped int?
final
framesPerSecond double?
final
framesReceived int?
final
frameWidth int?
final
hashCode int
The hash code for this object.
no setterinherited
headerBytesReceived int?
final
id String?
finalinherited
jitter double?
final
jitterBufferDelay double?
final
jitterBufferEmittedCount int?
final
keyFramesDecoded int?
final
kind String?
final
lastPacketReceivedTimestamp double?
final
mediaType String?
final
minPlayoutDelay double?
final
nackCount int?
final
packetsLost int?
final
packetsReceived int?
final
pliCount int?
final
qpSum int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssrc int?
final
timestamp double?
finalinherited
totalAssemblyTime double?
final
totalDecodeTime double?
final
totalInterFrameDelay double?
final
totalProcessingDelay double?
final
totalSquaredInterFrameDelay double?
final
trackId String?
final
transportId String?
final
type String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
writeTo(StringBuffer out) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) RtcInboundRtpVideoStream?