toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'RTCInboundRTPVideoStream{id: $id, type: $type, '
      'timestamp: $timestamp, transportId: $transportId, qpSum: $qpSum, '
      'lastPacketReceivedTimestamp: $lastPacketReceivedTimestamp, '
      'nackCount: $nackCount, firCount: $firCount, pliCount: $pliCount, '
      'packetsLost: $packetsLost, keyFramesDecoded: $keyFramesDecoded, '
      'totalSquaredInterFrameDelay: $totalSquaredInterFrameDelay, '
      'totalAssemblyTime: $totalAssemblyTime, frameHeight: $frameHeight, '
      'frameWidth: $frameWidth, framesDropped: $framesDropped, '
      'framesReceived: $framesReceived, framesPerSecond: $framesPerSecond, '
      'framesDecoded: $framesDecoded, '
      'totalInterFrameDelay: $totalInterFrameDelay, '
      'decoderImplementation: $decoderImplementation, kind: $kind, '
      'trackId: $trackId, jitterBufferDelay: $jitterBufferDelay, '
      'ssrc: $ssrc, mediaType: $mediaType, '
      'minPlayoutDelay: $minPlayoutDelay, '
      'headerBytesReceived: $headerBytesReceived, '
      'jitterBufferEmittedCount: $jitterBufferEmittedCount, '
      'codecId: $codecId, bytesReceived: $bytesReceived, '
      'totalProcessingDelay: $totalProcessingDelay, jitter: $jitter, '
      'packetsReceived: $packetsReceived, totalDecodeTime: $totalDecodeTime}';
}