RtcVideoDimension class

Available extensions
Annotations

Constructors

RtcVideoDimension({required int width, required int height})
const
RtcVideoDimension.zero()
const

Properties

area int
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
isEmpty bool
Returns true if the area is zero or negative.
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
width int
final

Methods

area() int

Available on RtcVideoDimension, provided by the RtcVideoDimensionHelpers extension

Simply returns the area
aspect() double

Available on RtcVideoDimension, provided by the RtcVideoDimensionHelpers extension

copyWith({int? width, int? height}) RtcVideoDimension
max() int

Available on RtcVideoDimension, provided by the RtcVideoDimensionHelpers extension

Returns the larger value
min() int

Available on RtcVideoDimension, provided by the RtcVideoDimensionHelpers extension

Returns the smaller value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited