RtcVideoParameters class

Implemented types
Available extensions
Annotations

Constructors

RtcVideoParameters({String? description, required RtcVideoDimension dimension, required RtcVideoEncoding encoding})
const

Properties

description String?
final
dimension RtcVideoDimension
final
encoding → RtcVideoEncoding
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

compareTo(RtcVideoParameters other) int
Compares this object to another object.
override
copyWith({String? description, RtcVideoDimension? dimension, RtcVideoEncoding? encoding}) RtcVideoParameters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited