StreamCallDominantSpeakerChangedEvent class

Event that is triggered when the dominant speaker changes

Inheritance
Available extensions

Constructors

StreamCallDominantSpeakerChangedEvent(StreamCallCid callCid, {required String userId, required String sessionId})
const

Properties

callCid StreamCallCid
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId String
final

Methods

emitIfNotNull(MutableSharedEmitter<StreamCallEvent> emitter) StreamCallEvent?

Available on StreamCallEvent?, provided by the StreamCallEventX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited