StreamCallMemberUpdatedPermissionEvent class

Event that is triggered when member permissions are updated in a call.

Inheritance
Available extensions

Constructors

StreamCallMemberUpdatedPermissionEvent(StreamCallCid callCid, {required DateTime createdAt, required List<CallMember> updatedMembers, required Map<String, List<String>> capabilitiesByRole, required CallMetadata metadata})
const

Properties

callCid StreamCallCid
finalinherited
capabilitiesByRole Map<String, List<String>>
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
metadata CallMetadata
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
updatedMembers List<CallMember>
final

Methods

emitIfNotNull(MutableSharedEmitter<StreamCallEvent> emitter) StreamCallEvent?

Available on StreamCallEvent?, provided by the StreamCallEventX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited