StreamCallModerationWarningEvent class

Event that is triggered when a user receives a moderation warning.

Inheritance
Available extensions

Constructors

StreamCallModerationWarningEvent(StreamCallCid callCid, {required DateTime createdAt, required String userId, required String message, Map<String, Object> custom = const {}})
const

Properties

callCid StreamCallCid
finalinherited
createdAt DateTime
final
custom Map<String, Object>
Custom data associated with the moderation action
final
hashCode int
The hash code for this object.
no setterinherited
message String
The warning message
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userId String
The user ID who is receiving the warning
final

Methods

emitIfNotNull(MutableSharedEmitter<StreamCallEvent> emitter) StreamCallEvent?

Available on StreamCallEvent?, provided by the StreamCallEventX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited