StreamClosedCaption class
- Annotations
Constructors
- StreamClosedCaption({required DateTime startTime, required DateTime endTime, required String speakerId, required String text, required CallUser user})
- StreamClosedCaption.fromEvent(StreamCallClosedCaptionsEvent event)
-
factory
Properties
- endTime → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speakerId → String
-
final
- startTime → DateTime
-
final
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - text → String
-
final
- user → CallUser
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited