StreamLivestreamThemeData class

Defines default property values for StreamLivestreamThemeData widgets.

Mixed-in types
Annotations

Constructors

StreamLivestreamThemeData({IconThemeData playIconTheme = const IconThemeData(color: Colors.white), IconThemeData pauseIconTheme = const IconThemeData(color: Colors.white), double playPauseIconSize = 64.0, Color liveButtonColor = const Color(0xff0066f5), Color backstageButtonColor = Colors.red, TextStyle callStateButtonTextStyle = const TextStyle(color: Colors.white), TextStyle participantCountTextStyle = const TextStyle(color: Colors.white), TextStyle durationTextStyle = const TextStyle(color: Colors.white), TextStyle backstageTextStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.w500, color: Colors.white), TextStyle backstageCounterTextStyle = const TextStyle(fontSize: 28, fontWeight: FontWeight.w500, color: Colors.white), TextStyle backstageParticipantsTextStyle = const TextStyle(fontSize: 16, color: Colors.white54), TextStyle liveEndedTextStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.w500, color: Colors.white), TextStyle liveEndedRecordingsTextStyle = const TextStyle(fontSize: 16, color: Colors.white54), IconThemeData participantIconTheme = const IconThemeData(color: Colors.white), IconThemeData speakerEnabledIconTheme = const IconThemeData(color: Colors.white), IconThemeData speakerDisabledIconTheme = const IconThemeData(color: Colors.white), IconThemeData expandIconTheme = const IconThemeData(color: Colors.white), IconThemeData contractIconTheme = const IconThemeData(color: Colors.white), EdgeInsets hostsGridPadding = const EdgeInsets.all(4), double hostsGridMainAxisSpacing = 4, double hostsGridCrossAxisSpacing = 4})
Creates a new instance of StreamLivestreamThemeData.
const

Properties

backstageButtonColor Color
The color of the "backstage" button on the control bar
final
backstageCounterTextStyle TextStyle
The TextStyle for the backstage counter
final
backstageParticipantsTextStyle TextStyle
The TextStyle for the backstage participants text
final
backstageTextStyle TextStyle
The TextStyle for the backstage text
final
callStateButtonTextStyle TextStyle
The TextStyle for the live/backstage button
final
contractIconTheme IconThemeData
The icon theme for the contract icon on the control bar
final
durationTextStyle TextStyle
The TextStyle for the duration count
final
expandIconTheme IconThemeData
The icon theme for the expand icon on the control bar
final
hashCode int
The hash code for this object.
no setteroverride
hostsGridCrossAxisSpacing double
Cross axis spacing between the hosts in the grid layout.
final
hostsGridMainAxisSpacing double
Main axis spacing between the hosts in the grid layout.
final
hostsGridPadding EdgeInsets
The padding between the hosts in the grid layout.
final
liveButtonColor Color
The color of the "live" button on the control bar
final
liveEndedRecordingsTextStyle TextStyle
The TextStyle for the live ended recordings text
final
liveEndedTextStyle TextStyle
The TextStyle for the live ended text
final
participantCountTextStyle TextStyle
The TextStyle for the participant count
final
participantIconTheme IconThemeData
The icon theme for the participant icon
final
pauseIconTheme IconThemeData
The icon theme for the pause icon for pausing the livestream
final
playIconTheme IconThemeData
The icon theme for the play icon for playing the livestream
final
playPauseIconSize double
The size of the play/pause icon
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerDisabledIconTheme IconThemeData
The icon theme for the speaker disabled icon on the control bar
final
speakerEnabledIconTheme IconThemeData
The icon theme for the speaker enabled icon on the control bar
final

Methods

copyWith({IconThemeData? playIconTheme, IconThemeData? pauseIconTheme, double? playPauseIconSize, Color? liveButtonColor, Color? backstageButtonColor, TextStyle? callStateButtonTextStyle, TextStyle? participantCountTextStyle, TextStyle? durationTextStyle, TextStyle? backstageTextStyle, TextStyle? backstageCounterTextStyle, TextStyle? backstageParticipantsTextStyle, TextStyle? liveEndedTextStyle, TextStyle? liveEndedRecordingsTextStyle, IconThemeData? participantIconTheme, IconThemeData? speakerEnabledIconTheme, IconThemeData? speakerDisabledIconTheme, IconThemeData? expandIconTheme, IconThemeData? contractIconTheme, EdgeInsets? hostsGridPadding, double? hostsGridMainAxisSpacing, double? hostsGridCrossAxisSpacing}) StreamLivestreamThemeData
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
lerp(StreamLivestreamThemeData other, double t) StreamLivestreamThemeData
Linearly interpolate between two StreamLivestreamThemeData themes.
merge(StreamLivestreamThemeData? other) StreamLivestreamThemeData
Merges one StreamLivestreamThemeData with the another.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override