speakerDisabledIconTheme property
The icon theme for the speaker disabled icon on the control bar
Implementation
final IconThemeData speakerDisabledIconTheme;
The icon theme for the speaker disabled icon on the control bar
final IconThemeData speakerDisabledIconTheme;