StreamOutgoingCallContent class

Represents the Outgoing Call state and UI, when the user is calling other people.

Inheritance

Constructors

StreamOutgoingCallContent({Key? key, required Call call, VoidCallback? onCancelCallTap, VoidCallback? onMicrophoneTap, VoidCallback? onCameraTap, StreamUserAvatarThemeData? singleParticipantAvatarTheme, StreamUserAvatarThemeData? multipleParticipantAvatarTheme, TextStyle? singleParticipantTextStyle, TextStyle? multipleParticipantTextStyle, TextStyle? callingLabelTextStyle, CallWidgetChildBuilder? callBackgroundWidgetBuilder, CallWidgetBuilderWithData<ParticipantsData>? participantsAvatarWidgetBuilder, CallWidgetBuilderWithData<ParticipantsData>? participantsDisplayNameWidgetBuilder})
Creates a new instance of StreamOutgoingCallContent.
const

Properties

call Call
Represents a call.
final
callBackgroundWidgetBuilder CallWidgetChildBuilder?
A widget that is placed behind the outgoing call UI instead of the Stream default
final
callingLabelTextStyle TextStyle?
Text style for the calling label.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
multipleParticipantAvatarTheme StreamUserAvatarThemeData?
Theme for the avatar in a call with multiple participants.
final
multipleParticipantTextStyle TextStyle?
Text style for the participant label in a call with multiple participants.
final
onCameraTap VoidCallback?
The action to perform when the camera button is tapped.
final
onCancelCallTap VoidCallback?
The action to perform when the cancel call button is tapped.
final
onMicrophoneTap VoidCallback?
The action to perform when the microphone button is tapped.
final
participantsAvatarWidgetBuilder CallWidgetBuilderWithData<ParticipantsData>?
Builder used to create a custom widget for participants avatars.
final
participantsDisplayNameWidgetBuilder CallWidgetBuilderWithData<ParticipantsData>?
Builder used to create a custom widget for participants display names.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleParticipantAvatarTheme StreamUserAvatarThemeData?
Theme for the avatar in a call with one participant.
final
singleParticipantTextStyle TextStyle?
Text style for the participant label in a call with one participant.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StreamOutgoingCallContent>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited