StreamRecordingSettings class
- Inheritance
-
- Object
- AbstractSettings
- StreamRecordingSettings
Constructors
- StreamRecordingSettings({bool audioOnly = false, RecordSettingsMode mode = RecordSettingsMode.disabled, RecordSettingsQuality quality = RecordSettingsQuality.n360p})
-
const
Properties
- audioOnly → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → RecordSettingsMode
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- quality → RecordSettingsQuality
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toOpenDto(
) → RecordSettingsRequest -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited