StreamTranscriptionSettings class

Inheritance

Constructors

StreamTranscriptionSettings({ClosedCaptionSettingsMode closedCaptionMode = ClosedCaptionSettingsMode.disabled, TranscriptionSettingsMode transcriptionMode = TranscriptionSettingsMode.disabled, TranscriptionSettingsLanguage language = TranscriptionSettingsLanguage.auto})
const

Properties

closedCaptionMode ClosedCaptionSettingsMode
final
hashCode int
The hash code for this object.
no setterinherited
language TranscriptionSettingsLanguage
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
transcriptionMode TranscriptionSettingsMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOpenDto() TranscriptionSettingsRequest
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited