StreamVideoQuality enum
Quality preset for a video output (RTMP broadcast, HLS track, or call recording). Mirrors the server-accepted alias values.
Values
- p360 → const StreamVideoQuality
-
const StreamVideoQuality('360p') - p480 → const StreamVideoQuality
-
const StreamVideoQuality('480p') - p720 → const StreamVideoQuality
-
const StreamVideoQuality('720p') - p1080 → const StreamVideoQuality
-
const StreamVideoQuality('1080p') - p1440 → const StreamVideoQuality
-
const StreamVideoQuality('1440p') - portrait360x640 → const StreamVideoQuality
-
const StreamVideoQuality('portrait-360x640') - portrait480x854 → const StreamVideoQuality
-
const StreamVideoQuality('portrait-480x854') - portrait720x1280 → const StreamVideoQuality
-
const StreamVideoQuality('portrait-720x1280') - portrait1080x1920 → const StreamVideoQuality
-
const StreamVideoQuality('portrait-1080x1920') - portrait1440x2560 → const StreamVideoQuality
-
const StreamVideoQuality('portrait-1440x2560')
Properties
- alias → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromAlias(
String alias) → StreamVideoQuality?
Constants
-
values
→ const List<
StreamVideoQuality> - A constant List of the values in this enum, in order of their declaration.