ToggleMicrophoneOption class

A widget that represents a call control option to toggle if the microphone is on or off.

Inheritance

Constructors

ToggleMicrophoneOption({Key? key, required Call call, CallParticipantState? localParticipant, IconData enabledMicrophoneIcon = Icons.mic_rounded, IconData disabledMicrophoneIcon = Icons.mic_off_rounded, Color? enabledMicrophoneIconColor, Color? disabledMicrophoneIconColor, Color? enabledMicrophoneBackgroundColor, Color? disabledMicrophoneBackgroundColor, bool? stopTrackOnMute})
Creates a new instance of ToggleMicrophoneOption.
const

Properties

call Call
Represents a call.
final
disabledMicrophoneBackgroundColor Color?
Color of the background when microphone is disabled
final
disabledMicrophoneIcon IconData
The icon that is shown when the microphone is disabled.
final
disabledMicrophoneIconColor Color?
Color of the icon when microphone is disabled
final
enabledMicrophoneBackgroundColor Color?
Color of the background when microphone is enabled
final
enabledMicrophoneIcon IconData
The icon that is shown when the microphone is enabled.
final
enabledMicrophoneIconColor Color?
Color of the icon when microphone is enabled
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
localParticipant CallParticipantState?
The current local participant. If provided this localParticipant will be used, otherwise the localParticipant of the call will be used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopTrackOnMute bool?
Determines if muting the microphone stops and releases (true) or keeps and silences (false) the audio track. Setting to false is necessary for "speaking-while-muted" detection on iOS and macOS.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited