TrackOption class abstract

Available extensions

Constructors

TrackOption()
const
TrackOption.disabled()
factory
TrackOption.enabled({MediaConstraints? constraints})
factory
TrackOption.fromSetting({required bool enabled})
factory
TrackOption.provided(RtcLocalTrack<MediaConstraints> track)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisabled bool

Available on TrackOption, provided by the TrackOptionX extension

no setter
isEnabled bool

Available on TrackOption, provided by the TrackOptionX extension

no setter
isProvided bool

Available on TrackOption, provided by the TrackOptionX extension

no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter
trackOrNull RtcLocalTrack<MediaConstraints>?

Available on TrackOption, provided by the TrackOptionX extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggle() TrackOption

Available on TrackOption, provided by the TrackOptionX extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited