VideoConstraints class abstract

Base class for options when creating a video track.

Inheritance

Constructors

VideoConstraints({String? deviceId, double? maxFrameRate, RtcVideoParameters params = RtcVideoParametersPresets.h720_16x9})
const

Properties

deviceId String?
The deviceId of the capture device to use. Available deviceIds can be obtained through flutter_webrtc:
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxFrameRate double?
Limit the maximum frameRate of the capture device.
final
params RtcVideoParameters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() MediaConstraints
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited