StreamVideoFlutterLocalizationsNl class

The translations for Dutch Flemish (nl).

Inheritance

Constructors

StreamVideoFlutterLocalizationsNl([String locale = 'nl'])

Properties

desktopScreenShareChooseDialogCancel → String
Cancel action to go back without sharing
no setteroverride
desktopScreenShareChooseDialogShare → String
Share action to start sharing
no setteroverride
desktopScreenShareChooseDialogTitle → String
Title for dialog to choose for a window or screen to share
no setteroverride
desktopScreenShareEntireScreen → String
Tab to select a screen to share
no setteroverride
desktopScreenShareWindow → String
Tab to select a single window to share
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
livestreamBackstage → String
The badge text shown when the call mode is backstage
no setteroverride
livestreamBackstageStartingIn → String
Label for livestream backstage when live stream counter is shown
no setteroverride
livestreamBackstageStartingSoon → String
Label for livestream backstage when live stream will soon start
no setteroverride
livestreamEndedStatus → String
Label shown when the livestream has already ended.
no setteroverride
livestreamEndedWatchRecordings → String
Label shown when the livestream has already ended listing the recordings.
no setteroverride
livestreamHostNotAvailable → String
Label shown when the host of the livestream is not available.
no setteroverride
livestreamLive → String
The badge text shown when the call mode is live
no setteroverride
localeName → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

livestreamBackstageParticipants(num count) → String
Label for livestream backstage showing participants count
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited