CallControlOption class
Widget that represents a call control option.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CallControlOption
Constructors
- CallControlOption({Key? key, required Widget icon, Color? iconColor, Color? disabledIconColor, double? elevation, Color? backgroundColor, Color? disabledBackgroundColor, OutlinedBorder? shape, EdgeInsetsGeometry? padding, VoidCallback? onPressed})
-
Creates a new instance of CallControlOption.
const
Properties
- backgroundColor → Color?
-
The background color of the call control option.
final
- disabledBackgroundColor → Color?
-
The background color of the call control option when it is disabled.
final
- disabledIconColor → Color?
-
The color of the icon of the call control option when it is disabled.
final
- elevation → double?
-
The elevation of the call control option.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget
-
The icon of the call control option.
final
- iconColor → Color?
-
The color of the icon of the call control option.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → VoidCallback?
-
The callback to invoke when the user taps on the call control option.
final
- padding → EdgeInsetsGeometry?
-
The padding applied to the call control option.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → OutlinedBorder?
-
The shape of the call control option.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited