CallMetadata class
- Annotations
Constructors
-
CallMetadata({required StreamCallCid cid, required CallDetails details, required CallSettings settings, required CallSessionData session, required Map<
String, CallUser> users, required Map<String, CallMember> members}) -
const
Properties
- cid → StreamCallCid
-
final
- details → CallDetails
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
members
→ Map<
String, CallMember> -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → CallSessionData
-
final
- settings → CallSettings
-
final
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited -
users
→ Map<
String, CallUser> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited