RtcIceCandidate class
Constructors
Properties
- address → String?
-
final
- candidateType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- ip → String?
-
final
- isRemote → bool?
-
final
- networkAdapterType → String?
-
final
- networkType → String?
-
final
- port → int?
-
final
- priority → int?
-
final
- protocol → String?
-
final
- relayProtocol → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → double?
-
finalinherited
- transportId → String?
-
final
- type → String?
-
finalinherited
- url → String?
-
final
- vpn → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTo(
StringBuffer out) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → RtcIceCandidate?