RtcInboundRtpAudioStream class
- Inheritance
- Implemented types
Constructors
- RtcInboundRtpAudioStream({String? id, String? type, double? timestamp, String? transportId, double? totalAudioEnergy, double? lastPacketReceivedTimestamp, double? audioLevel, int? packetsLost, int? totalSamplesReceived, int? concealmentEvents, int? removedSamplesForAcceleration, String? kind, String? trackId, double? jitterBufferDelay, int? ssrc, int? concealedSamples, String? mediaType, double? totalSamplesDuration, int? headerBytesReceived, int? insertedSamplesForDeceleration, int? packetsDiscarded, int? fecPacketsReceived, int? jitterBufferEmittedCount, String? codecId, int? bytesReceived, double? jitter, int? packetsReceived, int? silentConcealedSamples, int? fecPacketsDiscarded})
-
const
Properties
- audioLevel → double?
-
final
- bytesReceived → int?
-
final
- codecId → String?
-
final
- concealedSamples → int?
-
final
- concealmentEvents → int?
-
final
- fecPacketsDiscarded → int?
-
final
- fecPacketsReceived → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBytesReceived → int?
-
final
- id → String?
-
finalinherited
- insertedSamplesForDeceleration → int?
-
final
- jitter → double?
-
final
- jitterBufferDelay → double?
-
final
- jitterBufferEmittedCount → int?
-
final
- kind → String?
-
final
- lastPacketReceivedTimestamp → double?
-
final
- mediaType → String?
-
final
- packetsDiscarded → int?
-
final
- packetsLost → int?
-
final
- packetsReceived → int?
-
final
- removedSamplesForAcceleration → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- silentConcealedSamples → int?
-
final
- ssrc → int?
-
final
- timestamp → double?
-
finalinherited
- totalAudioEnergy → double?
-
final
- totalSamplesDuration → double?
-
final
- totalSamplesReceived → int?
-
final
- trackId → String?
-
final
- transportId → String?
-
final
- type → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
writeTo(
StringBuffer out) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → RtcInboundRtpAudioStream?