RtcMediaStreamTrackLocalAudio class
- Inheritance
- Implemented types
Constructors
Properties
- detached → bool?
-
final
- ended → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- kind → String?
-
final
- mediaSourceId → String?
-
final
- remoteSource → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → double?
-
finalinherited
- trackIdentifier → String?
-
final
- type → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
writeTo(
StringBuffer out) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → RtcMediaStreamTrackLocalAudio?