RtcMediaStreamTrackRemoteVideo class
- Inheritance
- Implemented types
Constructors
- RtcMediaStreamTrackRemoteVideo({String? id, String? type, double? timestamp, String? kind, int? frameHeight, int? frameWidth, int? framesReceived, int? framesDecoded, int? framesDropped, double? totalFramesDuration, double? totalFreezesDuration, int? freezeCount, int? pauseCount, bool? detached, bool? ended, bool? remoteSource, double? jitterBufferDelay, String? trackIdentifier, double? totalPausesDuration, int? jitterBufferEmittedCount, double? sumOfSquaredFramesDuration})
-
const
Properties
- detached → bool?
-
final
- ended → bool?
-
final
- frameHeight → int?
-
final
- framesDecoded → int?
-
final
- framesDropped → int?
-
final
- framesReceived → int?
-
final
- frameWidth → int?
-
final
- freezeCount → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- jitterBufferDelay → double?
-
final
- jitterBufferEmittedCount → int?
-
final
- kind → String?
-
final
- pauseCount → int?
-
final
- remoteSource → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sumOfSquaredFramesDuration → double?
-
final
- timestamp → double?
-
finalinherited
- totalFramesDuration → double?
-
final
- totalFreezesDuration → double?
-
final
- totalPausesDuration → double?
-
final
- trackIdentifier → String?
-
final
- type → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
writeTo(
StringBuffer out) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → RtcMediaStreamTrackRemoteVideo?