RtcRemoteInboundRtp class
- Inheritance
- Implemented types
Constructors
Properties
- codecId → String?
-
final
- fractionLost → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- jitter → double?
-
final
- kind → String?
-
final
- outboundId → String?
-
final
- packetsLost → int?
-
final
- roundTripTime → double?
-
final
- roundTripTimeMeasurements → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssrc → int?
-
final
- timestamp → double?
-
finalinherited
- totalRoundTripTime → double?
-
final
- transportId → String?
-
final
- type → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTo(
StringBuffer out) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited