SubscriptionChange class
Constructors
- SubscriptionChange.remove({required String userId, required String sessionId, required String trackIdPrefix, required SfuTrackTypeVideo? trackType})
-
SubscriptionChange.set({required String userId, required String sessionId, required String trackIdPrefix, required Map<
SfuTrackTypeVideo, RtcVideoDimension> ? trackTypes}) - SubscriptionChange.update({required String userId, required String sessionId, required String trackIdPrefix, required SfuTrackTypeVideo? trackType, RtcVideoDimension? videoDimension})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- subscribed → bool
-
final
- trackId ↔ String?
-
getter/setter pair
- trackIdPrefix → String
-
final
- trackType ↔ SfuTrackTypeVideo?
-
getter/setter pair
-
trackTypes
↔ Map<
SfuTrackTypeVideo, RtcVideoDimension> ? -
getter/setter pair
- userId → String
-
final
- videoDimension ↔ RtcVideoDimension?
-
getter/setter pair
Methods
-
getSubscriptions(
) → Map< String, SfuSubscriptionDetails> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toSubscription(
) → SfuSubscriptionDetails
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited